package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.dt.DtEnterCompanyQueryParam;
import com.xdf.creative.base.vo.creative.DtEnterCompanyQueryVo;
import com.xdf.creative.module.entity.DtEnterCompany;
import com.xdf.creative.module.service.DtEnterCompanyService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-05-11
 */
@Slf4j
@RestController
@RequestMapping("/dtEnterCompany")
@Api("API")
public class DtEnterCompanyController extends BaseController {

    @Autowired
    private DtEnterCompanyService dtEnterCompanyService;


    /**
     * 清理数据
     * @return
     * @throws Exception
     */
    @PostMapping("/cleanParkCompany")
    @ApiOperation(value = "清理数据DtEnterCompany对象", notes = "清理数据", response = ApiResult.class)
    public ApiResult  cleanParkCompany() throws Exception {
        return dtEnterCompanyService.cleanParkCompany();
    }


    /**
     * 添加
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加DtEnterCompany对象", notes = "添加", response = ApiResult.class)
    public ApiResult<Boolean> addDtEnterCompany(@Valid @RequestBody DtEnterCompany dtEnterCompany) throws Exception {
        boolean flag = dtEnterCompanyService.save(dtEnterCompany);
        return ApiResult.result(flag);
    }

    /**
     * 修改
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改DtEnterCompany对象", notes = "修改", response = ApiResult.class)
    public ApiResult<Boolean> updateDtEnterCompany(@Valid @RequestBody DtEnterCompany dtEnterCompany) throws Exception {
        boolean flag = dtEnterCompanyService.updateById(dtEnterCompany);
        return ApiResult.result(flag);
    }

    /**
     * 删除
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除DtEnterCompany对象", notes = "删除", response = ApiResult.class)
    public ApiResult<Boolean> deleteDtEnterCompany(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = dtEnterCompanyService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取DtEnterCompany对象详情", notes = "查看", response = DtEnterCompanyQueryVo.class)
    public ApiResult<DtEnterCompanyQueryVo> getDtEnterCompany(@Valid @RequestBody IdParam idParam) throws Exception {
        DtEnterCompanyQueryVo dtEnterCompanyQueryVo = dtEnterCompanyService.getDtEnterCompanyById(idParam.getId());
        return ApiResult.ok(dtEnterCompanyQueryVo);
    }

    /**
     * 分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取DtEnterCompany分页列表", notes = "分页列表", response = DtEnterCompanyQueryVo.class)
    public ApiResult<PageTool<DtEnterCompanyQueryVo>> getDtEnterCompanyPageList(@RequestBody DtEnterCompanyQueryParam dtEnterCompanyQueryParam) throws Exception {
        PageTool<DtEnterCompanyQueryVo> pageList = dtEnterCompanyService.getDtEnterCompanyPageList(dtEnterCompanyQueryParam);
        return ApiResult.ok(pageList);
    }

    @PostMapping("/getUserList")
    @ApiOperation(value = "获取DtEnterCompany分页列表", notes = "分页列表", response = DtEnterCompanyQueryVo.class)
    public ApiResult<PageTool<DtEnterCompanyQueryVo>> getDtEnterCompanyUserList(@RequestBody DtEnterCompanyQueryParam dtEnterCompanyQueryParam) throws Exception {
        PageTool<DtEnterCompanyQueryVo> pageList = dtEnterCompanyService.getDtEnterCompanyUserList(dtEnterCompanyQueryParam);
        return ApiResult.ok(pageList);
    }

    @PostMapping("/getHomeList")
    @ApiOperation(value = "获取DtEnterCompany分页列表", notes = "分页列表", response = DtEnterCompanyQueryVo.class)
    public ApiResult<PageTool<DtEnterCompanyQueryVo>> getDtEnterCompanyHomeList(@RequestBody DtEnterCompanyQueryParam dtEnterCompanyQueryParam) throws Exception {
        if(null==dtEnterCompanyQueryParam.getOrgParkId()){
            return ApiResult.fail("请选择园区！");
        }
        PageTool<DtEnterCompanyQueryVo> pageList = dtEnterCompanyService.getDtEnterCompanyHomeList(dtEnterCompanyQueryParam);
        return ApiResult.ok(pageList);
    }

}

