package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.dt.DtUploadCompanyQueryParam;
import com.xdf.creative.base.vo.dt.DtUploadCompanyQueryVo;
import com.xdf.creative.module.entity.DtUploadCompany;
import com.xdf.creative.module.service.DtUploadCompanyService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 企业上传 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-05-07
 */
@Slf4j
@RestController
@RequestMapping("/dtUploadCompany")
@Api("企业上传 API")
public class DtUploadCompanyController extends BaseController {

    @Autowired
    private DtUploadCompanyService dtUploadCompanyService;

    /**
     * 添加企业上传
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加DtUploadCompany对象", notes = "添加企业上传", response = ApiResult.class)
    public ApiResult<Boolean> addDtUploadCompany(@Valid @RequestBody DtUploadCompany dtUploadCompany) throws Exception {
        boolean flag = dtUploadCompanyService.save(dtUploadCompany);
        return ApiResult.result(flag);
    }

    /**
     * 修改企业上传
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改DtUploadCompany对象", notes = "修改企业上传", response = ApiResult.class)
    public ApiResult<Boolean> updateDtUploadCompany(@Valid @RequestBody DtUploadCompany dtUploadCompany) throws Exception {
        boolean flag = dtUploadCompanyService.updateById(dtUploadCompany);
        return ApiResult.result(flag);
    }

    /**
     * 删除企业上传
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除DtUploadCompany对象", notes = "删除企业上传", response = ApiResult.class)
    public ApiResult<Boolean> deleteDtUploadCompany(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = dtUploadCompanyService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取企业上传
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取DtUploadCompany对象详情", notes = "查看企业上传", response = DtUploadCompanyQueryVo.class)
    public ApiResult<DtUploadCompanyQueryVo> getDtUploadCompany(@Valid @RequestBody IdParam idParam) throws Exception {
        DtUploadCompanyQueryVo dtUploadCompanyQueryVo = dtUploadCompanyService.getDtUploadCompanyById(idParam.getId());
        return ApiResult.ok(dtUploadCompanyQueryVo);
    }

    /**
     * 企业上传分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取DtUploadCompany分页列表", notes = "企业上传分页列表", response = DtUploadCompanyQueryVo.class)
    public ApiResult<PageTool<DtUploadCompanyQueryVo>> getDtUploadCompanyPageList(@RequestBody DtUploadCompanyQueryParam dtUploadCompanyQueryParam) throws Exception {
        PageTool<DtUploadCompanyQueryVo> pageList = dtUploadCompanyService.getDtUploadCompanyPageList(dtUploadCompanyQueryParam);
        return ApiResult.ok(pageList);
    }




}

