package com.xdf.creative.module.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.dt.DtEnterCompanyQueryParam;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.CompanyBaseInfoVO;
import com.xdf.creative.base.vo.CompanyInfoDocument;
import com.xdf.creative.base.vo.creative.DtEnterCompanyQueryVo;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.enums.dt.DisposeStateEnum;
import com.xdf.creative.enums.dt.UploadCompanyStateEnum;
import com.xdf.creative.module.entity.DtEnterCompany;
import com.xdf.creative.module.entity.DtUploadCompany;
import com.xdf.creative.module.mapper.DtEnterCompanyMapper;
import com.xdf.creative.module.service.DtEnterCompanyService;
import com.xdf.creative.module.service.DtUploadCompanyService;
import com.xdf.creative.util.HttpClient;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.io.Serializable;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author lgw
 * @since 2020-05-11
 */
@Slf4j
@Service
public class DtEnterCompanyServiceImpl extends BaseServiceImpl<DtEnterCompanyMapper, DtEnterCompany> implements DtEnterCompanyService {


    @Value("${xdf_company_info_id_url}")
    private String xdfInfoIdUrl;
    @Value("${xdf_company_info_name_url}")
    private String xdfInfoNameUrl;
    @Value("${xdf_company_es_url}")
    private String esInfoUrl;

    private SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
    @Autowired
    private DtEnterCompanyMapper dtEnterCompanyMapper;
    @Autowired
    private DtUploadCompanyService dtUploadCompanyService;

    @Override
    public DtEnterCompanyQueryVo getDtEnterCompanyById(Serializable id) throws Exception {
        return dtEnterCompanyMapper.getDtEnterCompanyById(id);
    }


    @Override
    public ApiResult cleanParkCompany() {
        //获取excle数据
        List<DtUploadCompany> uploadCompanyList = dtUploadCompanyService.list(new QueryWrapper<DtUploadCompany>().eq("dispose_state", DisposeStateEnum.INFO_STATE_TYPE_ENUM.getCode()));
        for (DtUploadCompany dtUploadCompany : uploadCompanyList
        ) {
            if (UploadCompanyStateEnum.INFO_STATE_ADD_ENUM.getCode().equals(dtUploadCompany.getState())) {
                changeCompanyInfo(dtUploadCompany);

            } else if (UploadCompanyStateEnum.INFO_STATE_UPDATE_ENUM.getCode().equals(dtUploadCompany.getState())) {
                //先删除后修改
                changeCompanyInfo(dtUploadCompany);

            } else if (UploadCompanyStateEnum.INFO_STATE_DEL_ENUM.getCode().equals(dtUploadCompany.getState())) {
                this.remove(new QueryWrapper<DtEnterCompany>().eq("company_name",dtUploadCompany.getCompanyName()));
            }
        }
        return ApiResult.ok();
    }

    @Transactional
    public void changeCompanyInfo(DtUploadCompany dtUploadCompany) {
        try {
            if (UploadCompanyStateEnum.INFO_STATE_UPDATE_ENUM.getCode().equals(dtUploadCompany.getState())) {
                //先删除后修改
                this.remove(new QueryWrapper<DtEnterCompany>().eq("company_name",dtUploadCompany.getCompanyName()));
            }
            DtEnterCompany dtEnterCompany = new DtEnterCompany();
            BeanUtils.copyProperties(dtUploadCompany, dtEnterCompany);
            dtEnterCompany.setUpdateTime(new Date());
            //开始拉取数据
            Map<String, String> map = new HashMap<String, String>();
            map.put("companyName", dtUploadCompany.getCompanyName());
            if (!StringUtil.isEmpty(dtUploadCompany.getSerialNumber())) {
                map.put("societyNum", dtUploadCompany.getSerialNumber());
            }
            //先从es拉取数据 如果没有从mysql库中拉取
            CompanyInfoDocument companyInfoDocument = getXdfEsCompanyInfo(map);
            if (null == companyInfoDocument) {
                CompanyBaseInfoVO companyBaseInfoVO = getXdfCompanyInfoByName(dtUploadCompany.getCompanyName());
                if(null==companyBaseInfoVO){
                    dtUploadCompany.setUpdateTime(new Date());
                    dtUploadCompany.setDisposeState(DisposeStateEnum.INFO_STATE_TYPE_NOT_FOUND.getCode());
                    dtUploadCompany.setState(UploadCompanyStateEnum.INFO_STATE_ADD_ENUM.getCode());
                    dtEnterCompany.setExist(StateEnum.DISABLE.getKey());
                    dtEnterCompany.setSort(0);
                }else{
                    dtEnterCompany.setExist(StateEnum.ENABLE.getKey());
                    dtEnterCompany.setSort(1);
                    if (StringUtil.isEmpty(dtEnterCompany.getSerialNumber())) {
                        dtEnterCompany.setSerialNumber(companyBaseInfoVO.getPropertyCode());
                    }
                    //注册资金
                    if (StringUtil.isEmpty(dtEnterCompany.getRegCapitalNo())) {
                        dtEnterCompany.setRegCapital(companyBaseInfoVO.getRegCapital());
                    }
                    //成立日期
                    if (null == dtEnterCompany.getEstiblishTime()) {
                        dtEnterCompany.setEstiblishTime(companyBaseInfoVO.getEstiblishTime());
                    }
                    //行业代码
                    if (StringUtil.isEmpty(dtEnterCompany.getCateName())) {
                        if (!StringUtil.isEmpty(companyBaseInfoVO.getCategoryName())) {
                            dtEnterCompany.setCateName(companyBaseInfoVO.getCategoryName());
                        }
                    }
                    //法人
                    if(StringUtil.isEmpty(dtEnterCompany.getLegalPersonName())){
                        dtEnterCompany.setLegalPersonName(companyBaseInfoVO.getLegalPersonName());
                    }

                    dtEnterCompany.setCompanyId(companyBaseInfoVO.getId());

                    dtUploadCompany.setUpdateTime(new Date());
                    dtUploadCompany.setDisposeState(DisposeStateEnum.INFO_STATE_TYPE_SUCCESS.getCode());
                    dtUploadCompany.setState(UploadCompanyStateEnum.INFO_STATE_INIT_ENUM.getCode());
                }
            } else {
                dtEnterCompany.setExist(StateEnum.ENABLE.getKey());
                //统一社会信用代码
                if (StringUtil.isEmpty(dtEnterCompany.getSerialNumber())) {
                    dtEnterCompany.setSerialNumber(companyInfoDocument.getSoci_num());
                }
                //注册资金
                if (StringUtil.isEmpty(dtEnterCompany.getRegCapitalNo())) {
                    dtEnterCompany.setRegCapitalNo(companyInfoDocument.getReg_val());
                    dtEnterCompany.setUnit(companyInfoDocument.getReg_unit());
                    dtEnterCompany.setRegCapital(companyInfoDocument.getReg_cpl());
                }else{
                    dtEnterCompany.setRegCapital(dtEnterCompany.getRegCapitalNo()+dtEnterCompany.getUnit());
                }
                //成立日期
                if (null == dtEnterCompany.getEstiblishTime()) {
                    try {
                        if (!StringUtil.isEmpty(companyInfoDocument.getEst_tm())) {
                            dtEnterCompany.setEstiblishTime(sdf.parse(companyInfoDocument.getEst_tm()));
                        }
                    } catch (ParseException e) {
                        log.error(dtEnterCompany.getCompanyName() + "日期转换失败：" + companyInfoDocument.getEst_tm());
                        e.printStackTrace();
                    }
                }
                    //法人
                if(StringUtil.isEmpty(dtEnterCompany.getLegalPersonName())){
                    dtEnterCompany.setLegalPersonName(companyInfoDocument.getFr_nm());
                }
                //行业代码
                if (StringUtil.isEmpty(dtEnterCompany.getCateName())) {
                    CompanyBaseInfoVO companyBaseInfoVO = getXdfCompanyInfoById(companyInfoDocument.getCom_id().toString());
                    if (!StringUtil.isEmpty(companyBaseInfoVO.getCategoryName())) {
                        dtEnterCompany.setCateName(companyBaseInfoVO.getCategoryName());
                    }
                    if (!StringUtil.isEmpty(companyInfoDocument.getCateg())) {
                        dtEnterCompany.setCateg(companyInfoDocument.getCateg());
                     }
                }

                dtEnterCompany.setCompanyId(companyInfoDocument.getCom_id());
                dtEnterCompany.setSort(1);
                if("Y".equals(companyInfoDocument.getIs_500_new())){
                    dtEnterCompany.setSort(dtEnterCompany.getSort()+1);
                }

                dtEnterCompany.setIsFiveNew(companyInfoDocument.getIs_500_new());

                if("Y".equals(companyInfoDocument.getIs_high_tec_new())){
                    dtEnterCompany.setSort(dtEnterCompany.getSort()+1);
                }
                dtEnterCompany.setIsHighTecNew(companyInfoDocument.getIs_high_tec_new());

                if("Y".equals(companyInfoDocument.getListed_com())){
                    dtEnterCompany.setSort(dtEnterCompany.getSort()+1);
                }
                dtEnterCompany.setListedCom(companyInfoDocument.getListed_com());

                if("Y".equals(companyInfoDocument.getIs_invest())){
                    dtEnterCompany.setSort(dtEnterCompany.getSort()+1);
                }
                dtEnterCompany.setIsInvest(companyInfoDocument.getIs_invest());

                dtUploadCompany.setUpdateTime(new Date());
                dtUploadCompany.setDisposeState(DisposeStateEnum.INFO_STATE_TYPE_SUCCESS.getCode());
                dtUploadCompany.setState(UploadCompanyStateEnum.INFO_STATE_INIT_ENUM.getCode());

            }
            dtUploadCompanyService.saveOrUpdate(dtUploadCompany);
            this.saveOrUpdate(dtEnterCompany);
        } catch (Exception e) {
            dtUploadCompany.setUpdateTime(new Date());
            dtUploadCompany.setDisposeState(DisposeStateEnum.INFO_STATE_TYPE_FAILE.getCode());
            dtUploadCompany.setState(UploadCompanyStateEnum.INFO_STATE_INIT_ENUM.getCode());
            dtUploadCompanyService.saveOrUpdate(dtUploadCompany);
        }


    }


    /**
     * 获取信东方es企业基本信息
     *
     * @return
     */
    public CompanyInfoDocument getXdfEsCompanyInfo(Map<String, String> map) {
        String body = null;
        CompanyInfoDocument companyInfoDocument = null;
        try {
            body = HttpClient.sendPostDataByMap(esInfoUrl, map, "utf-8");
            JSONObject object = JSON.parseObject(body);

            if (JSONArray.parseArray(object.get("data").toString()).size() > 0) {
                String companyInfo = JSONArray.parseArray(object.get("data").toString()).get(0).toString();
                companyInfoDocument = JSONObject.parseObject(companyInfo, CompanyInfoDocument.class);
            } else {
                companyInfoDocument = null;
            }
        } catch (IOException e) {
            log.error("企业" + map.get("companyName") + "拉取数据异常！");
            e.printStackTrace();
        }
        return companyInfoDocument;
    }

    /**
     * 获取信东方企业基本信息
     *
     * @return
     */
    public CompanyBaseInfoVO getXdfCompanyInfoById(String companyId) {
        String body = "";
        CompanyBaseInfoVO companyBaseInfoVO = null;
        try {
            body = HttpClient.sendGetData(xdfInfoIdUrl + companyId, "utf-8");
            JSONObject object = JSON.parseObject(body);
            String companyInfo = object.get("data").toString();
            companyBaseInfoVO = JSONObject.parseObject(companyInfo, CompanyBaseInfoVO.class);
        } catch (IOException e) {
            log.error("企业id" + companyId + "拉取数据异常！");
            e.printStackTrace();
        }
        return companyBaseInfoVO;
    }

    /**
     * 获取信东方企业基本信息
     *
     * @return
     */
    public CompanyBaseInfoVO getXdfCompanyInfoByName(String name) {
        String body = "";
        CompanyBaseInfoVO companyBaseInfoVO = null;
        try {
            body = HttpClient.sendGetData(xdfInfoNameUrl + name, "utf-8");
            JSONObject object = JSON.parseObject(body);
            String companyInfo = object.get("data").toString();
            companyBaseInfoVO = JSONObject.parseObject(companyInfo, CompanyBaseInfoVO.class);
        } catch (IOException e) {
            log.error("企业名称" + name + "拉取数据异常！");
            e.printStackTrace();
        }
        return companyBaseInfoVO;
    }



    @Override
    public PageTool<DtEnterCompanyQueryVo> getDtEnterCompanyPageList(DtEnterCompanyQueryParam dtEnterCompanyQueryParam) throws Exception {
        Page page = setPageParam(dtEnterCompanyQueryParam);
        IPage<DtEnterCompanyQueryVo> iPage = dtEnterCompanyMapper.getDtEnterCompanyPageList(page, dtEnterCompanyQueryParam);
        return new PageTool(iPage);
    }

    @Override
    public PageTool<DtEnterCompanyQueryVo> getDtEnterCompanyUserList(DtEnterCompanyQueryParam dtEnterCompanyQueryParam) throws Exception {
        dtEnterCompanyQueryParam.setOrgParkId(getOrganizeId());
        Page page = setPageParam(dtEnterCompanyQueryParam);
        IPage<DtEnterCompanyQueryVo> iPage = dtEnterCompanyMapper.getDtEnterCompanyUserList(page, dtEnterCompanyQueryParam);
        return new PageTool(iPage);
    }

    @Override
    public PageTool<DtEnterCompanyQueryVo> getDtEnterCompanyHomeList(DtEnterCompanyQueryParam dtEnterCompanyQueryParam) throws Exception {

        Page page = setPageParam(dtEnterCompanyQueryParam);
        IPage<DtEnterCompanyQueryVo> iPage = dtEnterCompanyMapper.getDtEnterCompanyHomeList(page, dtEnterCompanyQueryParam);
        return new PageTool(iPage);
    }
}
