package com.xdf.creative.module.service.impl;

import com.alibaba.druid.util.StringUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.DtUploadCompanyDescript;
import com.xdf.creative.base.params.dt.DtUploadCompanyQueryParam;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.dt.DtUploadCompanyQueryVo;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.enums.dt.DisposeStateEnum;
import com.xdf.creative.enums.dt.UploadCompanyStateEnum;
import com.xdf.creative.module.entity.DtParkInfoDraft;
import com.xdf.creative.module.entity.DtUploadCompany;
import com.xdf.creative.module.mapper.DtUploadCompanyMapper;
import com.xdf.creative.module.service.DtParkInfoDraftService;
import com.xdf.creative.module.service.DtUploadCompanyService;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * <p>
 * 企业上传 服务实现类
 * </p>
 *
 * @author lgw
 * @since 2020-05-07
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class DtUploadCompanyServiceImpl extends BaseServiceImpl<DtUploadCompanyMapper, DtUploadCompany> implements DtUploadCompanyService {

    private SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

    @Autowired
    private DtUploadCompanyMapper dtUploadCompanyMapper;

    @Autowired
    private DtParkInfoDraftService dtParkInfoDraftService;

    @Override
    public DtUploadCompanyQueryVo getDtUploadCompanyById(Serializable id) {
        return dtUploadCompanyMapper.getDtUploadCompanyById(id);
    }

    @Override
    public ApiResult addCompanyByExcel(List<DtUploadCompanyDescript> list) {
        int excelCount = list.size();
        int addCount = 0;
        int updateCount =0;
        int successCount = 0;
        List<DtUploadCompany> companyList = new ArrayList<>();
        for (int i = 0; i < list.size(); i++) {
            DtUploadCompanyDescript dtUploadCompanyDescript = list.get(i);
            DtUploadCompany dtUploadCompany = new DtUploadCompany();
            BeanUtils.copyProperties(dtUploadCompanyDescript, dtUploadCompany);
            if (StringUtil.isEmpty(dtUploadCompanyDescript.getCompanyType())) {
                dtUploadCompany.setCompanyType(StateEnum.DISABLE.getKey());
            } else {
                dtUploadCompany.setCompanyType(Integer.parseInt(dtUploadCompanyDescript.getCompanyType()));
            }
            if (!StringUtil.isEmpty(dtUploadCompanyDescript.getEstiblishTime())) {
                System.out.println(dtUploadCompanyDescript.toString());
                try {
                    dtUploadCompany.setEstiblishTime(sdf.parse(dtUploadCompanyDescript.getEstiblishTime()));
                } catch (ParseException e) {
                    log.error(dtUploadCompany.getCompanyName() + "日期转换失败：" + dtUploadCompanyDescript.getEstiblishTime());
                    e.printStackTrace();
                }
            }
            companyList.add(dtUploadCompany);
        }
        for (DtUploadCompany dtUploadCompany : companyList
        ) {
            try {
                DtUploadCompany dtUploadCompanyOld = this.getOne(new QueryWrapper<DtUploadCompany>().eq("company_name", dtUploadCompany.getCompanyName().trim()));
                if (null == dtUploadCompanyOld) {
                    dtUploadCompany.setCreateTime(new Date());
                    dtUploadCompany.setDisposeState(DisposeStateEnum.INFO_STATE_TYPE_ENUM.getCode());
                    dtUploadCompany.setState(UploadCompanyStateEnum.INFO_STATE_ADD_ENUM.getCode());
                    dtUploadCompany.setCompanyName(dtUploadCompany.getCompanyName().trim());
                    DtParkInfoDraft dtParkInfoDraft = dtParkInfoDraftService.getOne(new QueryWrapper<DtParkInfoDraft>().eq("name", dtUploadCompany.getParkName()));
                    if (null != dtParkInfoDraft) {
                        dtUploadCompany.setOrgParkId(dtParkInfoDraft.getOrganizeId());
                        dtUploadCompany.setBizParkId(dtParkInfoDraft.getDateParkId());
                        this.saveOrUpdate(dtUploadCompany);
                        addCount++;
                    }else{
                        log.error("园区名未找到："+dtUploadCompany.getParkName());
                    }
                } else {
                    Long oldCompanyId = dtUploadCompanyOld.getId();
                    BeanUtils.copyProperties(dtUploadCompany, dtUploadCompanyOld);
                    dtUploadCompanyOld.setId(oldCompanyId);
                    dtUploadCompanyOld.setUpdateTime(new Date());
                    dtUploadCompanyOld.setDisposeState(DisposeStateEnum.INFO_STATE_TYPE_ENUM.getCode());
                    dtUploadCompanyOld.setState(UploadCompanyStateEnum.INFO_STATE_UPDATE_ENUM.getCode());
                    this.saveOrUpdate(dtUploadCompanyOld);
                    updateCount++;
                }

            } catch (Exception e) {
                log.error("出错企业："+dtUploadCompany.getCompanyName());
                successCount++;
            }
        }
        System.out.println("总计" + excelCount + "条，增量数据"+addCount+"条，更新数据"+updateCount+"条，执行失败" +  successCount + "条");
        return ApiResult.ok("总计" + excelCount + "条，增量数据"+addCount+"条，更新数据"+updateCount+"条，执行失败" +  successCount + "条");

    }






    @Override
    public PageTool<DtUploadCompanyQueryVo> getDtUploadCompanyPageList(DtUploadCompanyQueryParam dtUploadCompanyQueryParam) throws Exception {
        Page page = setPageParam(dtUploadCompanyQueryParam);
        IPage<DtUploadCompanyQueryVo> iPage = dtUploadCompanyMapper.getDtUploadCompanyPageList(page, dtUploadCompanyQueryParam);
        return new PageTool(iPage);
    }

}
