package com.xdf.creative.util;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.xdf.creative.base.vo.CompanyBaseInfoVO;
import com.xdf.creative.base.vo.CompanyInfoDocument;
import org.apache.http.HttpStatus;
import org.apache.http.NameValuePair;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;

import com.alibaba.fastjson.JSON;


/**
 * @author : lgw
 * @date : 18:08 2020/5/9
 */
public class HttpClient {

    /**
     * post请求传输map数据
     *
     * @param url
     * @param map
     * @param encoding
     * @return
     * @throws ClientProtocolException
     * @throws IOException
     */
    public static String sendPostDataByMap(String url, Map<String, String> map, String encoding) throws ClientProtocolException, IOException {
        String result = "";

        // 创建httpclient对象
        CloseableHttpClient httpClient = HttpClients.createDefault();
        // 创建post方式请求对象
        HttpPost httpPost = new HttpPost(url);

        // 装填参数
        List<NameValuePair> nameValuePairs = new ArrayList<NameValuePair>();
        if (map != null) {
            for (Entry<String, String> entry : map.entrySet()) {
                nameValuePairs.add(new BasicNameValuePair(entry.getKey(), entry.getValue()));
            }
        }

        // 设置参数到请求对象中
        httpPost.setEntity(new UrlEncodedFormEntity(nameValuePairs, encoding));

        // 设置header信息
        // 指定报文头【Content-type】、【User-Agent】
        httpPost.setHeader("Content-type", "application/x-www-form-urlencoded");
        httpPost.setHeader("User-Agent", "Mozilla/4.0 (compatible; MSIE 5.0; Windows NT; DigExt)");

        // 执行请求操作，并拿到结果（同步阻塞）
        CloseableHttpResponse response = httpClient.execute(httpPost);
        // 获取结果实体
        // 判断网络连接状态码是否正常(0--200都数正常)
        if (response.getStatusLine().getStatusCode() == HttpStatus.SC_OK) {
            result = EntityUtils.toString(response.getEntity(), "utf-8");
        }
        // 释放链接
        response.close();

        return result;
    }

    /**
     * post请求传输json数据
     *
     * @param url
     * @param json
     * @param encoding
     * @return
     * @throws ClientProtocolException
     * @throws IOException
     */
    public static String sendPostDataByJson(String url, String json, String encoding) throws ClientProtocolException, IOException {
        String result = "";

        // 创建httpclient对象
        CloseableHttpClient httpClient = HttpClients.createDefault();

        // 创建post方式请求对象
        HttpPost httpPost = new HttpPost(url);

        // 设置参数到请求对象中
        StringEntity stringEntity = new StringEntity(json, ContentType.APPLICATION_JSON);
        stringEntity.setContentEncoding("utf-8");
        httpPost.setEntity(stringEntity);

        // 执行请求操作，并拿到结果（同步阻塞）
        CloseableHttpResponse response = httpClient.execute(httpPost);

        // 获取结果实体
        // 判断网络连接状态码是否正常(0--200都数正常)
        if (response.getStatusLine().getStatusCode() == HttpStatus.SC_OK) {
            result = EntityUtils.toString(response.getEntity(), "utf-8");
        }
        // 释放链接
        response.close();

        return result;
    }

    /**
     * get请求传输数据
     *
     * @param url
     * @param encoding
     * @return
     * @throws ClientProtocolException
     * @throws IOException
     */
    public static String sendGetData(String url, String encoding) throws ClientProtocolException, IOException {
        String result = "";

        // 创建httpclient对象
        CloseableHttpClient httpClient = HttpClients.createDefault();

        // 创建get方式请求对象
        HttpGet httpGet = new HttpGet(url);
        httpGet.addHeader("Content-type", "application/json");
        // 通过请求对象获取响应对象
        CloseableHttpResponse response = httpClient.execute(httpGet);

        // 获取结果实体
        // 判断网络连接状态码是否正常(0--200都数正常)
        if (response.getStatusLine().getStatusCode() == HttpStatus.SC_OK) {
            result = EntityUtils.toString(response.getEntity(), "utf-8");
        }
        // 释放链接
        response.close();

        return result;
    }

    public static String testSendPostDataByMap() throws ClientProtocolException, IOException {
        String url = "http://192.168.1.101:8700/xdf/elastic/companyInfo/getCompanyInfoByNameAndSocNum";
        Map<String, String> map = new HashMap<String, String>();
        map.put("companyName", "上海浦宸埃尔医疗科技股份有限公司");
        map.put("societyNum", "91310000660712441J");
        String body = sendPostDataByMap(url, map, "utf-8");
        JSONObject object = JSON.parseObject(body);
        String companyInfo =JSONArray.parseArray( object.get("data").toString()).get(0).toString();
        String regNum = JSONObject.parseObject(companyInfo, CompanyInfoDocument.class).getReg_num();
        String companyId = JSONObject.parseObject(companyInfo).get("com_id").toString();
        System.out.println("注册号码：" + regNum);
        return companyId;

    }

    public static void testSendPostDataByJson() throws ClientProtocolException, IOException {
        String url = "http://192.168.1.101:8700/xdf/elastic/companyInfo/getCompanyInfoByNameAndSocNum";
        Map<String, String> map = new HashMap<String, String>();
        map.put("companyName", "上海浦宸埃尔医疗科技股份有限公司");
        map.put("societyNum", "91310000660712441J");
        String body = sendPostDataByJson(url, JSON.toJSONString(map), "utf-8");

    }

    public static void testSendGetData(String companyId) throws ClientProtocolException, IOException {
        String url = "http://xdfdata.com/xdf/company/company/baseInfo/"+companyId;
        String body = sendGetData(url, "utf-8");
        JSONObject object = JSON.parseObject(body);
        String companyInfo =object.get("data").toString();
        String categoryName = JSONObject.parseObject(companyInfo, CompanyBaseInfoVO.class).getCategoryName();
        System.out.println("行业名称：" + categoryName);
    }


    public static void main(String args[]){
        try {
            String companyId = testSendPostDataByMap();
            testSendGetData(companyId);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
